import Foundation

/**
 A string key used in markdown to indicate special elements
 */
enum ShorthandMarkdownKey: String {

    /// A standard url
    /// Format:  `![url](<url>;<text>)`
    case url

    /// An image
    /// Format:  `![image](<imageId>;<caption?>]`
    case image

    /// Statistics about hiking
    /// Format: `![hiking-stats](<`
    case hikingStatistics = "hiking-stats"

    /// A video
    /// Format: `![video](<fileId>;<alt>;<option1...>]`
    case video

    /// An SVG image
    /// Format: `![svg](<fileId>;<<x>;<y>;<width>;<height>?>)`

    /// A variable number of download buttons for file downloads
    /// Format: `[download](<<fileId>,<text>,<download-filename?>;...)`
    case downloadButtons = "download"

    /// A box with a title and content
    /// Format: `![box](<title>;<body>)`
    case box

    /// A 3D model to display
    /// Format: `![model](<file>;<description>)`
    case model

    /// A pretty link to another page on the site.
    /// Format: `![page](<pageId>)`
    case pageLink = "page"

    /// A large button to an external page.
    /// Format: `![external](<<url>;<text>...>`
    case externalLink = "external"

    /// Additional HTML code include verbatim into the page.
    /// Format: `![html](<fileId>)`
    case includedHtml = "html"

}
