
struct WebsiteImage {

    private let prefix1x: String

    private let prefix2x: String

    private let altText: String

    private let ext: String

    init(image: FeedEntryData.Image) {
        self.init(rawImagePath: image.rawImagePath,
                  width: image.width,
                  height: image.height,
                  altText: image.altText)
    }

    init(rawImagePath: String, width: Int, height: Int, altText: String) {
        let (prefix, ext) = rawImagePath.fileNameAndExtension
        self.prefix1x = "\(prefix)@\(width)x\(height)"
        self.prefix2x = "\(prefix)@\(width*2)x\(height*2)"
        self.altText = altText.htmlEscaped()
        self.ext = ext ?? "jpg"
    }

    var content: String {
        var result = "<picture>"
        result += "<source type='image/avif' srcset='\(prefix1x).avif 1x, \(prefix2x).avif 2x'/>"
        result += "<source type='image/webp' srcset='\(prefix1x).webm 1x, \(prefix1x).webm 2x'/>"
        result += "<img srcset='\(prefix2x).\(ext) 2x' src='\(prefix1x).\(ext)' loading='lazy' alt='\(altText)'/>"
        result += "</picture>"
        return result
    }
}
