import SwiftUI
import HighlightedTextEditor

struct PageTitleView: View {

    @ObservedObject
    var page: LocalizedPage

    var body: some View {
        TextField("", text: $page.title)
            .font(.title)
            .textFieldStyle(.plain)
    }
}

struct PageContentView: View {

    @ObservedObject
    var page: Page

    @Environment(\.language)
    private var language

    @EnvironmentObject
    private var content: Content

    @State
    private var isGeneratingWebsite = false

    init(page: Page) {
        self.page = page
    }

    var body: some View {
        LocalizedPageContentView(pageId: page.id, page: page.localized(in: language))
            .id(page.id + language.rawValue)
    }

}

extension PageContentView: MainContentView {

    init(item: Page) {
        self.page = item
    }

    static let itemDescription = "a page"
}

#Preview {
    PageContentView(page: .empty)
}
