import SwiftUI

struct LocalizedTagDetailView: View {

    @Binding
    var tagIsVisible: Bool

    @ObservedObject
    var tag: LocalizedTag

    @EnvironmentObject
    private var content: Content

    @State
    private var showImagePicker = false

    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                Toggle("Appears in overviews", isOn: $tagIsVisible)
                    .toggleStyle(.switch)
                    .font(.callout)
                    .foregroundStyle(.secondary)

                Text("Name")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                TextField("", text: $tag.name)

                Text("URL String")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                TextField("", text: $tag.urlComponent)

                Text("Original url")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                Text(tag.originalUrl ?? "-")
                    .padding(.top, 1)
                    .padding(.bottom)

                Text("Subtitle")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                OptionalTextField("", text: $tag.subtitle)

                Text("Description")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                OptionalTextField("", text: $tag.description)

                Text("Thumbnail")
                    .font(.callout)
                    .foregroundStyle(.secondary)
                Button(action: { showImagePicker = true }) {
                    Text(tag.thumbnail?.id ?? "Select")
                }
                .buttonStyle(.plain)
                .foregroundStyle(.blue)
            }
            .padding()
        }
        .sheet(isPresented: $showImagePicker) {
            ImagePickerView(showImagePicker: $showImagePicker) { image in
                tag.thumbnail = image
            }
        }
    }
}

#Preview {
    LocalizedTagDetailView(
        tagIsVisible: .constant(true),
        tag: Tag.mock.english)
}
